@@ -62,7 +62,8 @@ class EndWinding(FrozenClass):
         object or dict can be given for pyleecan Object"""
 
         if init_dict is not None:  # Initialisation by dict
-            assert init_dict == {"__class__": "EndWinding"}
+            assert "__class__" in init_dict
+            assert init_dict["__class__"] == "EndWinding"
         if init_str is not None:  # Initialisation by str
             assert type(init_str) is str
         # The class is frozen, for now it's impossible to add new properties
