@@ -28,11 +28,11 @@ except ImportError as error:
     comp_force_nodal = error
 
 try:
-    from ..Methods.Simulation.ForceTensor.comp_magnetrosctrictive_tensor import (
-        comp_magnetrosctrictive_tensor,
+    from ..Methods.Simulation.ForceTensor.comp_magnetostrictive_tensor import (
+        comp_magnetostrictive_tensor,
     )
 except ImportError as error:
-    comp_magnetrosctrictive_tensor = error
+    comp_magnetostrictive_tensor = error
 
 try:
     from ..Methods.Simulation.ForceTensor.element_loop import element_loop
@@ -72,18 +72,18 @@ class ForceTensor(Force):
         )
     else:
         comp_force_nodal = comp_force_nodal
-    # cf Methods.Simulation.ForceTensor.comp_magnetrosctrictive_tensor
-    if isinstance(comp_magnetrosctrictive_tensor, ImportError):
-        comp_magnetrosctrictive_tensor = property(
+    # cf Methods.Simulation.ForceTensor.comp_magnetostrictive_tensor
+    if isinstance(comp_magnetostrictive_tensor, ImportError):
+        comp_magnetostrictive_tensor = property(
             fget=lambda x: raise_(
                 ImportError(
-                    "Can't use ForceTensor method comp_magnetrosctrictive_tensor: "
-                    + str(comp_magnetrosctrictive_tensor)
+                    "Can't use ForceTensor method comp_magnetostrictive_tensor: "
+                    + str(comp_magnetostrictive_tensor)
                 )
             )
         )
     else:
-        comp_magnetrosctrictive_tensor = comp_magnetrosctrictive_tensor
+        comp_magnetostrictive_tensor = comp_magnetostrictive_tensor
     # cf Methods.Simulation.ForceTensor.element_loop
     if isinstance(element_loop, ImportError):
         element_loop = property(
@@ -104,6 +104,7 @@ class ForceTensor(Force):
     def __init__(
         self,
         group="stator core",
+        tensor=None,
         is_periodicity_t=None,
         is_periodicity_a=None,
         is_agsf_transfer=False,
@@ -130,6 +131,8 @@ class ForceTensor(Force):
             # Overwrite default value with init_dict content
             if "group" in list(init_dict.keys()):
                 group = init_dict["group"]
+            if "tensor" in list(init_dict.keys()):
+                tensor = init_dict["tensor"]
             if "is_periodicity_t" in list(init_dict.keys()):
                 is_periodicity_t = init_dict["is_periodicity_t"]
             if "is_periodicity_a" in list(init_dict.keys()):
@@ -144,6 +147,7 @@ class ForceTensor(Force):
                 logger_name = init_dict["logger_name"]
         # Set the properties (value check and convertion are done in setter)
         self.group = group
+        self.tensor = tensor
         # Call Force init
         super(ForceTensor, self).__init__(
             is_periodicity_t=is_periodicity_t,
@@ -163,6 +167,7 @@ class ForceTensor(Force):
         # Get the properties inherited from Force
         ForceTensor_str += super(ForceTensor, self).__str__()
         ForceTensor_str += 'group = "' + str(self.group) + '"' + linesep
+        ForceTensor_str += "tensor = " + str(self.tensor) + linesep
         return ForceTensor_str
 
     def __eq__(self, other):
@@ -176,6 +181,8 @@ class ForceTensor(Force):
             return False
         if other.group != self.group:
             return False
+        if other.tensor != self.tensor:
+            return False
         return True
 
     def compare(self, other, name="self", ignore_list=None):
@@ -191,6 +198,8 @@ class ForceTensor(Force):
         diff_list.extend(super(ForceTensor, self).compare(other, name=name))
         if other._group != self._group:
             diff_list.append(name + ".group")
+        if other._tensor != self._tensor:
+            diff_list.append(name + ".tensor")
         # Filter ignore differences
         diff_list = list(filter(lambda x: x not in ignore_list, diff_list))
         return diff_list
@@ -203,6 +212,9 @@ class ForceTensor(Force):
         # Get size of the properties inherited from Force
         S += super(ForceTensor, self).__sizeof__()
         S += getsizeof(self.group)
+        if self.tensor is not None:
+            for key, value in self.tensor.items():
+                S += getsizeof(value) + getsizeof(key)
         return S
 
     def as_dict(self, **kwargs):
@@ -215,6 +227,9 @@ class ForceTensor(Force):
         # Get the properties inherited from Force
         ForceTensor_dict = super(ForceTensor, self).as_dict(**kwargs)
         ForceTensor_dict["group"] = self.group
+        ForceTensor_dict["tensor"] = (
+            self.tensor.copy() if self.tensor is not None else None
+        )
         # The class name is added to the dict for deserialisation purpose
         # Overwrite the mother class name
         ForceTensor_dict["__class__"] = "ForceTensor"
@@ -224,6 +239,7 @@ class ForceTensor(Force):
         """Set all the properties to None (except pyleecan object)"""
 
         self.group = None
+        self.tensor = None
         # Set to None the properties inherited from Force
         super(ForceTensor, self)._set_None()
 
@@ -244,3 +260,23 @@ class ForceTensor(Force):
         :Type: str
         """,
     )
+
+    def _get_tensor(self):
+        """getter of tensor"""
+        return self._tensor
+
+    def _set_tensor(self, value):
+        """setter of tensor"""
+        if type(value) is int and value == -1:
+            value = dict()
+        check_var("tensor", value, "dict")
+        self._tensor = value
+
+    tensor = property(
+        fget=_get_tensor,
+        fset=_set_tensor,
+        doc=u"""Force model(s) to be used
+
+        :Type: dict
+        """,
+    )
