@@ -52,11 +52,6 @@ try:
 except ImportError as error:
     get_Zs = error
 
-try:
-    from ..Methods.Machine.LamSlot.comp_radius_mid_yoke import comp_radius_mid_yoke
-except ImportError as error:
-    comp_radius_mid_yoke = error
-
 try:
     from ..Methods.Machine.LamSlot.comp_periodicity import comp_periodicity
 except ImportError as error:
@@ -165,18 +160,6 @@ class LamSlot(Lamination):
         )
     else:
         get_Zs = get_Zs
-    # cf Methods.Machine.LamSlot.comp_radius_mid_yoke
-    if isinstance(comp_radius_mid_yoke, ImportError):
-        comp_radius_mid_yoke = property(
-            fget=lambda x: raise_(
-                ImportError(
-                    "Can't use LamSlot method comp_radius_mid_yoke: "
-                    + str(comp_radius_mid_yoke)
-                )
-            )
-        )
-    else:
-        comp_radius_mid_yoke = comp_radius_mid_yoke
     # cf Methods.Machine.LamSlot.comp_periodicity
     if isinstance(comp_periodicity, ImportError):
         comp_periodicity = property(
