@@ -57,6 +57,11 @@ try:
 except ImportError as error:
     get_bore_desc = error
 
+try:
+    from ..Methods.Machine.LamSlotMulti.comp_periodicity import comp_periodicity
+except ImportError as error:
+    comp_periodicity = error
+
 
 from numpy import array, array_equal
 from ._check import InitUnKnowClassError
@@ -158,6 +163,18 @@ class LamSlotMulti(Lamination):
         )
     else:
         get_bore_desc = get_bore_desc
+    # cf Methods.Machine.LamSlotMulti.comp_periodicity
+    if isinstance(comp_periodicity, ImportError):
+        comp_periodicity = property(
+            fget=lambda x: raise_(
+                ImportError(
+                    "Can't use LamSlotMulti method comp_periodicity: "
+                    + str(comp_periodicity)
+                )
+            )
+        )
+    else:
+        comp_periodicity = comp_periodicity
     # save and copy methods are available in all object
     save = save
     copy = copy
@@ -168,6 +185,7 @@ class LamSlotMulti(Lamination):
         self,
         slot_list=-1,
         alpha=None,
+        sym_dict_enforced=None,
         L1=0.35,
         mat_type=-1,
         Nrvd=0,
@@ -203,6 +221,8 @@ class LamSlotMulti(Lamination):
                 slot_list = init_dict["slot_list"]
             if "alpha" in list(init_dict.keys()):
                 alpha = init_dict["alpha"]
+            if "sym_dict_enforced" in list(init_dict.keys()):
+                sym_dict_enforced = init_dict["sym_dict_enforced"]
             if "L1" in list(init_dict.keys()):
                 L1 = init_dict["L1"]
             if "mat_type" in list(init_dict.keys()):
@@ -232,6 +252,7 @@ class LamSlotMulti(Lamination):
         # Set the properties (value check and convertion are done in setter)
         self.slot_list = slot_list
         self.alpha = alpha
+        self.sym_dict_enforced = sym_dict_enforced
         # Call Lamination init
         super(LamSlotMulti, self).__init__(
             L1=L1,
@@ -271,6 +292,9 @@ class LamSlotMulti(Lamination):
             + linesep
             + linesep
         )
+        LamSlotMulti_str += (
+            "sym_dict_enforced = " + str(self.sym_dict_enforced) + linesep
+        )
         return LamSlotMulti_str
 
     def __eq__(self, other):
@@ -286,6 +310,8 @@ class LamSlotMulti(Lamination):
             return False
         if not array_equal(other.alpha, self.alpha):
             return False
+        if other.sym_dict_enforced != self.sym_dict_enforced:
+            return False
         return True
 
     def compare(self, other, name="self", ignore_list=None):
@@ -316,6 +342,8 @@ class LamSlotMulti(Lamination):
                 )
         if not array_equal(other.alpha, self.alpha):
             diff_list.append(name + ".alpha")
+        if other._sym_dict_enforced != self._sym_dict_enforced:
+            diff_list.append(name + ".sym_dict_enforced")
         # Filter ignore differences
         diff_list = list(filter(lambda x: x not in ignore_list, diff_list))
         return diff_list
@@ -331,6 +359,9 @@ class LamSlotMulti(Lamination):
             for value in self.slot_list:
                 S += getsizeof(value)
         S += getsizeof(self.alpha)
+        if self.sym_dict_enforced is not None:
+            for key, value in self.sym_dict_enforced.items():
+                S += getsizeof(value) + getsizeof(key)
         return S
 
     def as_dict(self, **kwargs):
@@ -355,6 +386,11 @@ class LamSlotMulti(Lamination):
             LamSlotMulti_dict["alpha"] = None
         else:
             LamSlotMulti_dict["alpha"] = self.alpha.tolist()
+        LamSlotMulti_dict["sym_dict_enforced"] = (
+            self.sym_dict_enforced.copy()
+            if self.sym_dict_enforced is not None
+            else None
+        )
         # The class name is added to the dict for deserialisation purpose
         # Overwrite the mother class name
         LamSlotMulti_dict["__class__"] = "LamSlotMulti"
@@ -365,6 +401,7 @@ class LamSlotMulti(Lamination):
 
         self.slot_list = None
         self.alpha = None
+        self.sym_dict_enforced = None
         # Set to None the properties inherited from Lamination
         super(LamSlotMulti, self)._set_None()
 
@@ -425,3 +462,23 @@ class LamSlotMulti(Lamination):
         :Type: ndarray
         """,
     )
+
+    def _get_sym_dict_enforced(self):
+        """getter of sym_dict_enforced"""
+        return self._sym_dict_enforced
+
+    def _set_sym_dict_enforced(self, value):
+        """setter of sym_dict_enforced"""
+        if type(value) is int and value == -1:
+            value = dict()
+        check_var("sym_dict_enforced", value, "dict")
+        self._sym_dict_enforced = value
+
+    sym_dict_enforced = property(
+        fget=_get_sym_dict_enforced,
+        fset=_set_sym_dict_enforced,
+        doc=u"""Dictionary to enforce the lamination symmetry
+
+        :Type: dict
+        """,
+    )
