@@ -139,6 +139,11 @@ try:
 except ImportError as error:
     get_label = error
 
+try:
+    from ..Methods.Machine.Lamination.get_yoke_side_line import get_yoke_side_line
+except ImportError as error:
+    get_yoke_side_line = error
+
 
 from ._check import InitUnKnowClassError
 from .Material import Material
@@ -413,6 +418,18 @@ class Lamination(FrozenClass):
         )
     else:
         get_label = get_label
+    # cf Methods.Machine.Lamination.get_yoke_side_line
+    if isinstance(get_yoke_side_line, ImportError):
+        get_yoke_side_line = property(
+            fget=lambda x: raise_(
+                ImportError(
+                    "Can't use Lamination method get_yoke_side_line: "
+                    + str(get_yoke_side_line)
+                )
+            )
+        )
+    else:
+        get_yoke_side_line = get_yoke_side_line
     # save and copy methods are available in all object
     save = save
     copy = copy
