@@ -82,6 +82,11 @@ try:
 except ImportError as error:
     comp_width_opening = error
 
+try:
+    from ..Methods.Slot.Slot.convert_to_SlotUD2 import convert_to_SlotUD2
+except ImportError as error:
+    convert_to_SlotUD2 = error
+
 try:
     from ..Methods.Slot.Slot.get_is_stator import get_is_stator
 except ImportError as error:
@@ -276,6 +281,18 @@ class Slot(FrozenClass):
         )
     else:
         comp_width_opening = comp_width_opening
+    # cf Methods.Slot.Slot.convert_to_SlotUD2
+    if isinstance(convert_to_SlotUD2, ImportError):
+        convert_to_SlotUD2 = property(
+            fget=lambda x: raise_(
+                ImportError(
+                    "Can't use Slot method convert_to_SlotUD2: "
+                    + str(convert_to_SlotUD2)
+                )
+            )
+        )
+    else:
+        convert_to_SlotUD2 = convert_to_SlotUD2
     # cf Methods.Slot.Slot.get_is_stator
     if isinstance(get_is_stator, ImportError):
         get_is_stator = property(
@@ -448,7 +465,7 @@ class Slot(FrozenClass):
 
     def _set_Zs(self, value):
         """setter of Zs"""
-        check_var("Zs", value, "int", Vmin=0, Vmax=1000)
+        check_var("Zs", value, "int", Vmin=0)
         self._Zs = value
 
     Zs = property(
@@ -458,6 +475,5 @@ class Slot(FrozenClass):
 
         :Type: int
         :min: 0
-        :max: 1000
         """,
     )
