@@ -9,6 +9,7 @@ from .....Classes.Material import Material
 from .....GUI.Dialog.DMachineSetup.SMHoleMag.Ui_SMHoleMag import Ui_SMHoleMag
 from .....GUI.Dialog.DMachineSetup.SMHoleMag.WHoleMag.WHoleMag import WHoleMag
 from .....Methods.Slot.Slot import SlotCheckError
+from .....Functions.Plot.set_plot_gui_icon import set_plot_gui_icon
 
 
 class SMHoleMag(Ui_SMHoleMag, QWidget):
@@ -19,7 +20,7 @@ class SMHoleMag(Ui_SMHoleMag, QWidget):
     # Information for DMachineSetup
     step_name = "Hole"
 
-    def __init__(self, machine, matlib, is_stator=False):
+    def __init__(self, machine, material_dict, is_stator=False):
         """Initialize the widget according to machine
 
         Parameters
@@ -28,8 +29,8 @@ class SMHoleMag(Ui_SMHoleMag, QWidget):
             A SMHoleMag widget
         machine : Machine
             current machine to edit
-        matlib : MatLib
-            Material Library
+        material_dict: dict
+            Materials dictionary (library + machine)
         is_stator : bool
             To adapt the GUI to set either the stator or the rotor
         """
@@ -39,7 +40,7 @@ class SMHoleMag(Ui_SMHoleMag, QWidget):
 
         # Saving arguments
         self.machine = machine
-        self.matlib = matlib
+        self.material_dict = material_dict
         self.is_stator = is_stator
 
         # Get the correct object to set
@@ -126,7 +127,9 @@ class SMHoleMag(Ui_SMHoleMag, QWidget):
             hole.Zh = self.obj.hole[0].Zh
         else:
             hole_index = self.obj.hole.index(hole)
-        tab = WHoleMag(self, is_mag=is_mag, index=hole_index, matlib=self.matlib)
+        tab = WHoleMag(
+            self, is_mag=is_mag, index=hole_index, material_dict=self.material_dict
+        )
         tab.saveNeeded.connect(self.emit_save)
         self.tab_hole.addTab(tab, "Hole " + str(hole_index + 1))
 
@@ -155,12 +158,13 @@ class SMHoleMag(Ui_SMHoleMag, QWidget):
             hole.Zh = self.machine.stator.winding.p * 2
         self.set_hole_pitch(self.obj.hole[0].Zh)
 
-        # We have to make sure the hole is right before truing to plot it
+        # We have to make sure the hole is right before trying to plot it
         error = self.check(self.obj)
         if error:  # Error => Display it
             QMessageBox().critical(self, self.tr("Error"), error)
-        else:  # No error => Plot the hole (No winding for LamSquirrelCage)
-            self.machine.plot(is_show_fig=True)
+        else:  # No error => Plot the lamination
+            self.obj.plot(is_show_fig=True)
+            set_plot_gui_icon()
 
     @staticmethod
     def check(lamination):
