@@ -19,7 +19,7 @@ class Ui_PWSlot12(object):
     def setupUi(self, PWSlot12):
         if not PWSlot12.objectName():
             PWSlot12.setObjectName(u"PWSlot12")
-        PWSlot12.resize(812, 470)
+        PWSlot12.resize(964, 503)
         PWSlot12.setMinimumSize(QSize(630, 470))
         PWSlot12.setMaximumSize(QSize(16777215, 16777215))
         self.horizontalLayout = QHBoxLayout(PWSlot12)
@@ -43,88 +43,94 @@ class Ui_PWSlot12(object):
 
         self.horizontalLayout.addLayout(self.verticalLayout_2)
 
-        self.widget = QWidget(PWSlot12)
-        self.widget.setObjectName(u"widget")
-        self.widget.setMinimumSize(QSize(250, 0))
-        self.widget.setMaximumSize(QSize(250, 16777215))
-        self.verticalLayout = QVBoxLayout(self.widget)
-        self.verticalLayout.setObjectName(u"verticalLayout")
+        self.scrollArea = QScrollArea(PWSlot12)
+        self.scrollArea.setObjectName(u"scrollArea")
+        self.scrollArea.setMinimumSize(QSize(270, 0))
+        self.scrollArea.setMaximumSize(QSize(270, 16777215))
+        self.scrollArea.setWidgetResizable(True)
+        self.scrollAreaWidgetContents = QWidget()
+        self.scrollAreaWidgetContents.setObjectName(u"scrollAreaWidgetContents")
+        self.scrollAreaWidgetContents.setGeometry(QRect(0, 0, 268, 479))
+        self.verticalLayout_3 = QVBoxLayout(self.scrollAreaWidgetContents)
+        self.verticalLayout_3.setObjectName(u"verticalLayout_3")
         self.gridLayout = QGridLayout()
         self.gridLayout.setObjectName(u"gridLayout")
-        self.in_R1 = QLabel(self.widget)
+        self.in_R1 = QLabel(self.scrollAreaWidgetContents)
         self.in_R1.setObjectName(u"in_R1")
 
         self.gridLayout.addWidget(self.in_R1, 0, 0, 1, 1)
 
-        self.lf_R1 = FloatEdit(self.widget)
+        self.lf_R1 = FloatEdit(self.scrollAreaWidgetContents)
         self.lf_R1.setObjectName(u"lf_R1")
 
         self.gridLayout.addWidget(self.lf_R1, 0, 1, 1, 1)
 
-        self.unit_R1 = QLabel(self.widget)
+        self.unit_R1 = QLabel(self.scrollAreaWidgetContents)
         self.unit_R1.setObjectName(u"unit_R1")
 
         self.gridLayout.addWidget(self.unit_R1, 0, 2, 1, 1)
 
-        self.in_R2 = QLabel(self.widget)
+        self.in_R2 = QLabel(self.scrollAreaWidgetContents)
         self.in_R2.setObjectName(u"in_R2")
 
         self.gridLayout.addWidget(self.in_R2, 1, 0, 1, 1)
 
-        self.lf_R2 = FloatEdit(self.widget)
+        self.lf_R2 = FloatEdit(self.scrollAreaWidgetContents)
         self.lf_R2.setObjectName(u"lf_R2")
 
         self.gridLayout.addWidget(self.lf_R2, 1, 1, 1, 1)
 
-        self.unit_R2 = QLabel(self.widget)
+        self.unit_R2 = QLabel(self.scrollAreaWidgetContents)
         self.unit_R2.setObjectName(u"unit_R2")
 
         self.gridLayout.addWidget(self.unit_R2, 1, 2, 1, 1)
 
-        self.in_H0 = QLabel(self.widget)
+        self.in_H0 = QLabel(self.scrollAreaWidgetContents)
         self.in_H0.setObjectName(u"in_H0")
 
         self.gridLayout.addWidget(self.in_H0, 2, 0, 1, 1)
 
-        self.lf_H0 = FloatEdit(self.widget)
+        self.lf_H0 = FloatEdit(self.scrollAreaWidgetContents)
         self.lf_H0.setObjectName(u"lf_H0")
 
         self.gridLayout.addWidget(self.lf_H0, 2, 1, 1, 1)
 
-        self.unit_H0 = QLabel(self.widget)
+        self.unit_H0 = QLabel(self.scrollAreaWidgetContents)
         self.unit_H0.setObjectName(u"unit_H0")
 
         self.gridLayout.addWidget(self.unit_H0, 2, 2, 1, 1)
 
-        self.in_H1 = QLabel(self.widget)
+        self.in_H1 = QLabel(self.scrollAreaWidgetContents)
         self.in_H1.setObjectName(u"in_H1")
 
         self.gridLayout.addWidget(self.in_H1, 3, 0, 1, 1)
 
-        self.lf_H1 = FloatEdit(self.widget)
+        self.lf_H1 = FloatEdit(self.scrollAreaWidgetContents)
         self.lf_H1.setObjectName(u"lf_H1")
 
         self.gridLayout.addWidget(self.lf_H1, 3, 1, 1, 1)
 
-        self.unit_H1 = QLabel(self.widget)
+        self.unit_H1 = QLabel(self.scrollAreaWidgetContents)
         self.unit_H1.setObjectName(u"unit_H1")
 
         self.gridLayout.addWidget(self.unit_H1, 3, 2, 1, 1)
 
-        self.verticalLayout.addLayout(self.gridLayout)
+        self.verticalLayout_3.addLayout(self.gridLayout)
 
         self.verticalSpacer = QSpacerItem(
             20, 40, QSizePolicy.Minimum, QSizePolicy.Expanding
         )
 
-        self.verticalLayout.addItem(self.verticalSpacer)
+        self.verticalLayout_3.addItem(self.verticalSpacer)
 
-        self.w_out = WWSlotOut(self.widget)
+        self.w_out = WWSlotOut(self.scrollAreaWidgetContents)
         self.w_out.setObjectName(u"w_out")
 
-        self.verticalLayout.addWidget(self.w_out)
+        self.verticalLayout_3.addWidget(self.w_out)
 
-        self.horizontalLayout.addWidget(self.widget)
+        self.scrollArea.setWidget(self.scrollAreaWidgetContents)
+
+        self.horizontalLayout.addWidget(self.scrollArea)
 
         QWidget.setTabOrder(self.lf_R1, self.lf_R2)
         QWidget.setTabOrder(self.lf_R2, self.lf_H0)
