@@ -1,9 +1,10 @@
 # -*- coding: utf-8 -*-
+from ....Functions.labels import STATOR_LAB, ROTOR_LAB, ROTOR_LAB_S, STATOR_LAB_S
 
 
 def get_lam_by_label(self, label):
-    """Returns the lamination by its labels. Accepted labels are 'Stator_X' and
-    'Rotor_X' with X the number of the lamination starting with 0.
+    """Returns the lamination by its labels. Accepted labels are 'Stator-X' and
+    'Rotor-X' with X the number of the lamination starting with 0.
     For convenience also 'Stator' or 'Rotor' are allowed here to get respective first
     stator or rotor lamination.
 
@@ -22,18 +23,23 @@ def get_lam_by_label(self, label):
     # prepare error message just in case
     err_msg = (
         f"'{label}' is not a valid input argument for label."
-        + " Only 'Stator_X' or 'Rotor_X', with X the index, are accepted."
+        + " Only 'Stator-X' or 'Rotor-X', with X the index, are accepted."
     )
 
+    # Short=>Label conversion
+    if STATOR_LAB not in label and ROTOR_LAB not in label:
+        label = label.replace(ROTOR_LAB_S, ROTOR_LAB)
+        label = label.replace(STATOR_LAB_S, STATOR_LAB)
+
     # split the label components
-    lam_str = label.split("_")
+    lam_str = label.split("-")
 
     # if no index is provided append index 0
     if len(lam_str) == 1:
-        label += "_0"
+        label += "-0"
 
     # check that 'Rotor' or 'Stator' is in label
-    if lam_str[0] not in ["Stator", "Rotor"]:
+    if lam_str[0] not in [STATOR_LAB, ROTOR_LAB]:
         raise LabelInputError(err_msg)
 
     # get the requested lamination index
