@@ -38,15 +38,7 @@ def run(self):
     self.gen_datakeeper_list(ref_simu)
 
     # Check if one of the simulation from the list matches the reference one
-    ref_simu_index = None
-    for ii, simu in enumerate(simu_dict["simulation_list"]):
-        if simu == ref_simu:
-            ref_simu_index = ii
-            break
-    if self.NAME == "Variable Load" and ref_simu_index is None:
-        logger.warning(
-            "Reference Operating point is not in OP_matrix, one extra simulation will be computed"
-        )
+    ref_simu_index = self.get_ref_simu_index(ref_simu, simu_dict)
 
     # Fill/initialize input/output parameters
     nb_simu = len(simu_dict["simulation_list"])
