@@ -38,8 +38,9 @@ def build_geometry(self, alpha=0, delta=0):
         )
 
     surf_list = list()
-
-    Zc = (self.H0 + (self.D0 / 2)) * exp(1j * (self.Alpha0))
+    # Modulo on Alpha for sym
+    Alpha0 = self.Alpha0 % (2 * pi / self.Zh)
+    Zc = (self.H0 + (self.D0 / 2)) * exp(1j * Alpha0)
     surf_list.append(
         Trapeze(
             point_ref=Zc,
